==> SJava_0.69-5-1.tar.gz: SJava/src/RSJava/CtoJava.h <==

/* #line 85 "CtoJava.cweb" */
#ifndef INTERFACE_MANAGER_CTOJAVA_H
#define INTERFACE_MANAGER_CTOJAVA_H

#define RS(a) RS_##a
#define RS_JAVA(a) RS_JAVA_##a

#include <jni.h>
#include <malloc.h>

/* #line 194 "CtoJava.cweb" */

/* #line 374 "CtoJava.cweb" */
extern jobject NullObject;

/* #line 407 "CtoJava.cweb" */
extern jclass OmegahatInterfaceManagerClass;
extern jmethodID BasicClassValueAccessors[8];


/* #line 858 "CtoJava.cweb" */
/* an enumerator for accessible Java types  */
enum java_types {JAVA_BOOLEAN, /* 0 */
                 JAVA_BYTE,    /* 1 */
                 JAVA_CHAR,    /* 2 */
                 JAVA_SHORT,   /* 3 */
                 JAVA_INT,     /* 4 */
                 JAVA_LONG,    /* 5 */
                 JAVA_FLOAT,   /* 6 */
                 JAVA_DOUBLE,  /* 7 */
                 JAVA_STRING,  /* 8 */
                 JAVA_OBJECT,  /* 9 */
                 JAVA_NAMED_REFERENCE, /* 10 */
                 JAVA_ANONYMOUS_REFERENCE, /* 11 */
                 JAVA_GENERIC_REFERENCE,  /* 12 */
                 RS_NAMED_REFERENCE,  /* 13 */
                 RS_ANONYMOUS_REFERENCE,  /* 14 */                 
                 JAVA_INVALID           /* 15 */
                };  

typedef enum java_types java_type;

/* #define N_JAVA_TYPES JAVA_INVALID */

#define N_JAVA_TYPES JAVA_NAMED_REFERENCE



/* #line 887 "CtoJava.cweb" */
typedef enum {FUZZY_FALSE, FUZZY_TRUE, FUZZY_MAYBE} FuzzyBoolean;



/* #line 112 "CtoJava.cweb" */
#if defined(PATH_SEPARATOR)
#undef PATH_SEPARATOR
#endif

#ifdef _WIN32
#define PATH_SEPARATOR ';'
#else /* UNIX */
#define PATH_SEPARATOR ':'
#endif


#ifdef __cplusplus
#define VMENV (env)->
#else
#define VMENV (*env)->
#endif

/* #line 379 "CtoJava.cweb" */
#define NULL_JAVA_OBJECT NullObject


/* #line 494 "CtoJava.cweb" */
/* macro to require finding method id, else return exception message
 */
#define MUST_GET_METHOD_ID(id, cls1, cls2, which, sig, env) if((id = get_method_id(cls1, cls2, which, sig,env))==NULL)\
   return java_method_exception(which);


/* #line 774 "CtoJava.cweb" */
             /* macros to guard conversions in the method interface */
#define VMNewStringAssign(name, string, env) {if((string) == NULL || \
    (name=VMENV NewStringUTF(env, (string)), get_Java_exception(NULL,env))) \
         return(nullStringException(string,env));}



/* #line 1395 "CtoJava.cweb" */
typedef void *(*alloc_fun)();
#define LOCAL_ALLOC(n) (alloc ? (*alloc)(n) : malloc(n))



/* #line 100 "CtoJava.cweb" */
#ifdef __cplusplus
extern "C" {
#endif
/* #line 200 "CtoJava.cweb" */
extern const char *create_Java_vm(char *user_classpath, const char *javaLibPath,
                                  const char *interfaceLibraryFile,
                                  char ** user_properties, int n_properties, 
                                  int RequireLibraries, jboolean initializeNative);
extern int exists_Java_vm(void);



/* #line 416 "CtoJava.cweb" */
const char *do_native_setup(jobject Manager, jobject nullObj, JNIEnv *env);

/* #line 592 "CtoJava.cweb" */
const char *RS_JAVA(getSystemProperty)(const char *name,  jboolean *isCopy, JNIEnv *env);

/* #line 669 "CtoJava.cweb" */
jobject RS(createForeignReference)(JNIEnv *env, jstring id, jstring className, jobjectArray types);


/* #line 789 "CtoJava.cweb" */
extern jobject getInterfaceManager(void);
extern jobject setInterfaceManager(jobject value, JNIEnv *env);

/* #line 979 "CtoJava.cweb" */
int whatJavaType(void *javaObject, long *length_p, char **type_p, JNIEnv *env);

/* #line 1053 "CtoJava.cweb" */
extern enum java_types which_java_type(const char *signature, jboolean *isArray, jboolean *builtIn, jboolean *isObject);

/* #line 1230 "CtoJava.cweb" */
extern  void *toJavaType(JNIEnv *env, java_type which, long length, void *data,
                         jboolean isArray);
/* #line 1413 "CtoJava.cweb" */
extern const char *fromJavaType(JNIEnv *env, jobject obj, java_type which, long n, void *ptr,
                                                     jboolean isArray, int sz, alloc_fun alloc);
/* #line 1642 "CtoJava.cweb" */
extern const char *interface_start_VM(char *classpath, char *omega_home,
                               char *interface_lib_path, 
                               char *java_lib_path, char **
                                      user_props, int n_props);
/* #line 1696 "CtoJava.cweb" */
jmethodID findGetPrimitiveMethodID(enum java_types which);

/* #line 1740 "CtoJava.cweb" */
JNIEnv *interface_VM_env(void);

JNIEnv *setJNIEnv(JNIEnv *env);
JNIEnv *getJNIEnv();
JNIEnv *getThreadJNIEnv(jboolean *wasAttached);
jint   releaseThreadJNIEnv(jboolean wasAttached);


/* #line 1858 "CtoJava.cweb" */
void computeJavaVM(JNIEnv *env);
JavaVM *getJavaVM();
void RS_JAVA(terminateJava)();

/* #line 104 "CtoJava.cweb" */
#ifdef __cplusplus
}
#endif
  
#endif /* end of conditional inclusion. */

==> SJava_0.78.0.tar.gz: SJava/src/RSJava/CtoJava.h <==

/* #line 85 "CtoJava.cweb" */
#ifndef INTERFACE_MANAGER_CTOJAVA_H
#define INTERFACE_MANAGER_CTOJAVA_H

#define RS(a) RS_##a
#define RS_JAVA(a) RS_JAVA_##a

#include <jni.h>

/* #line 194 "CtoJava.cweb" */

/* #line 374 "CtoJava.cweb" */
extern jobject NullObject;

/* #line 407 "CtoJava.cweb" */
extern jclass OmegahatInterfaceManagerClass;
extern jmethodID BasicClassValueAccessors[8];


/* #line 858 "CtoJava.cweb" */
/* an enumerator for accessible Java types  */
enum java_types {JAVA_BOOLEAN, /* 0 */
                 JAVA_BYTE,    /* 1 */
                 JAVA_CHAR,    /* 2 */
                 JAVA_SHORT,   /* 3 */
                 JAVA_INT,     /* 4 */
                 JAVA_LONG,    /* 5 */
                 JAVA_FLOAT,   /* 6 */
                 JAVA_DOUBLE,  /* 7 */
                 JAVA_STRING,  /* 8 */
                 JAVA_OBJECT,  /* 9 */
                 JAVA_NAMED_REFERENCE, /* 10 */
                 JAVA_ANONYMOUS_REFERENCE, /* 11 */
                 JAVA_GENERIC_REFERENCE,  /* 12 */
                 RS_NAMED_REFERENCE,  /* 13 */
                 RS_ANONYMOUS_REFERENCE,  /* 14 */                 
                 JAVA_INVALID           /* 15 */
                };  

typedef enum java_types java_type;

/* #define N_JAVA_TYPES JAVA_INVALID */

#define N_JAVA_TYPES JAVA_NAMED_REFERENCE



/* #line 887 "CtoJava.cweb" */
typedef enum {FUZZY_FALSE, FUZZY_TRUE, FUZZY_MAYBE} FuzzyBoolean;



/* #line 112 "CtoJava.cweb" */
#if defined(PATH_SEPARATOR)
#undef PATH_SEPARATOR
#endif

#ifdef _WIN32
#define PATH_SEPARATOR ';'
#else /* UNIX */
#define PATH_SEPARATOR ':'
#endif


#ifdef __cplusplus
#define VMENV (env)->
#else
#define VMENV (*env)->
#endif

/* #line 379 "CtoJava.cweb" */
#define NULL_JAVA_OBJECT NullObject


/* #line 494 "CtoJava.cweb" */
/* macro to require finding method id, else return exception message
 */
#define MUST_GET_METHOD_ID(id, cls1, cls2, which, sig, env) if((id = get_method_id(cls1, cls2, which, sig,env))==NULL)\
   return java_method_exception(which);


/* #line 774 "CtoJava.cweb" */
             /* macros to guard conversions in the method interface */
#define VMNewStringAssign(name, string, env) {if((string) == NULL || \
    (name=VMENV NewStringUTF(env, (string)), get_Java_exception(NULL,env))) \
         return(nullStringException(string,env));}

/* #line 1395 "CtoJava.cweb" */
typedef void *(*alloc_fun)();

/* #line 100 "CtoJava.cweb" */
#ifdef __cplusplus
extern "C" {
#endif
/* #line 200 "CtoJava.cweb" */
extern const char *create_Java_vm(char *user_classpath, const char *javaLibPath,
                                  const char *interfaceLibraryFile,
                                  char ** user_properties, int n_properties, 
                                  int RequireLibraries, jboolean initializeNative);
extern int exists_Java_vm(void);



/* #line 416 "CtoJava.cweb" */
const char *do_native_setup(jobject Manager, jobject nullObj, JNIEnv *env);

/* #line 592 "CtoJava.cweb" */
const char *RS_JAVA(getSystemProperty)(JNIEnv *env, const char *name);

/* #line 669 "CtoJava.cweb" */
jobject RS(createForeignReference)(JNIEnv *env, jstring id, jstring className, jobjectArray types);


/* #line 789 "CtoJava.cweb" */
extern jobject getInterfaceManager(void);
extern jobject setInterfaceManager(jobject value, JNIEnv *env);

/* #line 979 "CtoJava.cweb" */
int whatJavaType(void *javaObject, long *length_p, char **type_p, JNIEnv *env);

/* #line 1053 "CtoJava.cweb" */
extern enum java_types which_java_type(const char *signature, jboolean *isArray, jboolean *builtIn, jboolean *isObject);

/* #line 1230 "CtoJava.cweb" */
extern  void *toJavaType(JNIEnv *env, java_type which, long length, void *data,
                         jboolean isArray);
/* #line 1413 "CtoJava.cweb" */
extern const char *fromJavaType(JNIEnv *env, jobject obj, java_type which, long n, void *ptr,
                                                     jboolean isArray, int sz, alloc_fun alloc);
/* #line 1642 "CtoJava.cweb" */
extern const char *interface_start_VM(char *classpath, char *omega_home,
                               char *interface_lib_path, 
                               char *java_lib_path, char **
                                      user_props, int n_props);
/* #line 1696 "CtoJava.cweb" */
jmethodID findGetPrimitiveMethodID(enum java_types which);

/* #line 1740 "CtoJava.cweb" */
JNIEnv *interface_VM_env(void);

JNIEnv *setJNIEnv(JNIEnv *env);
JNIEnv *getJNIEnv();
JNIEnv *getThreadJNIEnv(jboolean *wasAttached);
jint   releaseThreadJNIEnv(jboolean wasAttached);


/* #line 1858 "CtoJava.cweb" */
void computeJavaVM(JNIEnv *env);
JavaVM *getJavaVM();
void RS_JAVA(terminateJava)();

/* #line 104 "CtoJava.cweb" */
#ifdef __cplusplus
}
#endif
  
#endif /* end of conditional inclusion. */
